@@ -29,10 +29,15 @@ class Project:
         """Get path to sketch directory"""
         return os.path.join('sketches', self.name)
 
+    @property
+    def ino_name(self):
+        """Get name of .ino file"""
+        return '%s.ino' % self.name
+
     @property
     def ino_path(self):
         """Get path to .ino file"""
-        return os.path.join(self.path, '%s.ino' % self.name)
+        return os.path.join(self.path, self.ino_name)
 
     def assert_name(self):
         """Assert the user set a project name"""
@@ -66,6 +71,7 @@ class Project:
         """Compile sketch using arduino-cli"""
         command = self.board.compile()
         self.log(command.safe_output)
+        # hack to allow path with spaces
         if command.is_successful():
             self.compile_statistics = CompileStatistics(command.output)
 
